Address
  {$ ::ctrl.member.address $}
Admin State Up
  {$ ctrl.member.admin_state_up | yesno $}
Member ID
  {$ ::ctrl.member.id $}
Operating Status
  {$ ctrl.member.operating_status | decode:ctrl.operatingStatus $}
Project ID
  {$ ::ctrl.member.project_id $}
Protocol Port
  {$ ::ctrl.member.protocol_port $}
Provisioning Status
  {$ ctrl.member.provisioning_status | decode:ctrl.provisioningStatus $}
Subnet ID
  {$ ctrl.member.subnet_id $}
Weight
  {$ ctrl.member.weight $}
Monitor Address
  {$ ::ctrl.member.monitor_address | noValue:('None' | translate) $}
Monitor Port
  {$ ::ctrl.member.monitor_port | noValue:('None' | translate) $}
Created At
  {$ ::ctrl.member.created_at $}
Updated At
  {$ ::ctrl.member.updated_at $}